@@ -120,7 +120,7 @@ class GenericDataset(Dataset, DataContainer, Container):
         # s = OrderedDict(description=self.description, meta=self.meta)  # super(...).__getstate__()
         # s.update(OrderedDict(data=self.getData()))
         s = OrderedDict(description=self.description,
-                        meta=self.meta,
+                        meta=self._meta,
                         data=self.data,
                         _STID=self._STID)
         return s
@@ -252,8 +252,8 @@ class ArrayDataset(DataWrapper, GenericDataset, Sequence, Typed):
         """ Can be encoded with serializableEncoder """
         # s = OrderedDict(description=self.description, meta=self.meta, data=self.data)  # super(...).__getstate__()
         s = OrderedDict(description=self.description,
-                        meta=self.meta,
-                        data=None if self.data is None else list(self.data),
+                        meta=self._meta,
+                        data=None if self.data is None else self.data,
                         type=self._type,
                         default=self._default,
                         typecode=self._typecode,
