@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 from ..dataset.odict import ODict
-from ..dataset.serializable import serialize
+from ..dataset.serializable import serialize, Serializable
 from ..dataset.classes import Classes
 from .urn import Urn, parseUrn, parse_poolurl
 from .versionable import Versionable
@@ -12,13 +12,11 @@ from .query import AbstractQuery, MetaQuery
 
 import logging
 import filelock
-from copy import deepcopy
+from copy import copy
 import os
 import sys
 from functools import lru_cache
 
-import pdb
-
 if sys.version_info[0] >= 3:  # + 0.1 * sys.version_info[1] >= 3.3:
     PY3 = True
     from urllib.parse import urlparse
@@ -36,7 +34,7 @@ lockpathbase = '/tmp/fdi_locks'  # + getpass.getuser()
 locktout = 10
 
 
-class ProductPool(Definable, Taggable, Versionable):
+class ProductPool(Definable, Taggable, Versionable, Serializable):
     """ A mechanism that can store and retrieve Products.
 
 A product pool should not be used directly by users. The general user should access data in a ProductPool through a ProductStorage instance.
@@ -59,15 +57,27 @@ When implementing a ProductPool, the following rules need to be applied:
         """
         super(ProductPool, self).__init__(**kwds)
 
-        self._poolname = poolname
-
-        self._poolpath, self._scheme, self._place, nm = \
-            parse_poolurl(poolurl)
-        self._poolurl = poolurl
-        # self._pathurl = pr.netloc + pr.path
-        # self._pathurl = None
         # {type|classname -> {'sn:[sn]'}}
         self._classes = ODict()
+        self.setPoolname(poolname)
+        self.setPoolurl(poolurl)
+        # self._pathurl = pr.netloc + pr.path
+        # self._pathurl = None
+
+    class ParameetersIncommpleteError(Exception):
+        pass
+
+    def setup(self):
+        """ Sets up interal machiney of this Pool, 
+        but only if self._poolname and self._poolurl are present.
+
+        Subclasses should implement own setup(), and
+        make sure that self._poolname and self._poolurl are present.
+        """
+
+        if not hasattr(self, '_poolname') or self._poolname is None or \
+           not hasattr(self, '_poolurl') or self._poolurl is None:
+            return
 
     def lockpath(self, op='w'):
         """ returns the appropriate path.
@@ -97,6 +107,8 @@ When implementing a ProductPool, the following rules need to be applied:
         """ override this to changes the output from the input one (default) to something else.
 
         """
+        if path is None:
+            return None
         base = self._poolpath
         if base != '':
             if path[0] == '/':
@@ -105,6 +117,58 @@ When implementing a ProductPool, the following rules need to be applied:
                 path = base + '/' + path
         return path
 
+    @property
+    def poolname(self):
+        """ for property getter
+        """
+        return self.getPoolname()
+
+    @poolname.setter
+    def poolname(self, poolname):
+        """ for property setter
+        """
+        self.setPoolname(poolname)
+
+    def getPoolname(self):
+        """ Gets the poolname of this pool as an Object. """
+        return self._poolname
+
+    def setPoolname(self, poolname):
+        """ Replaces the current poolname of this pool.
+        """
+        s = (not hasattr(self, '_poolname') or self._poolname is None)
+        self._poolname = poolname
+        # call setup only if poolname was None
+        if s:
+            self.setup()
+
+    @property
+    def poolurl(self):
+        """ for property getter
+        """
+        return self.getPoolurl()
+
+    @poolurl.setter
+    def poolurl(self, poolurl):
+        """ for property setter
+        """
+        self.setPoolurl(poolurl)
+
+    def getPoolurl(self):
+        """ Gets the poolurl of this pool as an Object. """
+        return self._poolurl
+
+    def setPoolurl(self, poolurl):
+        """ Replaces the current poolurl of this pool.
+        """
+        s = (not hasattr(self, '_poolurl') or self._poolurl is None)
+        self._poolpath, self._scheme, self._place, nm = \
+            parse_poolurl(poolurl)
+        self._poolurl = poolurl
+        # call setup only if poolurl was None
+        if s:
+            self.setup()
+
     def accept(self, visitor):
         """ Hook for adding functionality to object
         through visitor pattern."""
@@ -241,20 +305,20 @@ When implementing a ProductPool, the following rules need to be applied:
         prod = resource
         sn = index
 
-        self._classes, self._tags, self._urns = self.readHK()
-        c, t, u = self._classes, self._tags, self._urns
-
-        # save a copy for rolling back
-        cs, ts, us = deepcopy(c), deepcopy(t), deepcopy(u)
-
-        if urn not in u:
-            raise ValueError(
-                '%s not found in pool %s.' % (urn, self.getId()))
-
         with filelock.FileLock(self.lockpath('w')),\
                 filelock.FileLock(self.lockpath('r')):
+
+            # get the latest HK
+            self._classes, self._tags, self._urns = self.readHK()
+            c, t, u = self._classes, self._tags, self._urns
+
+            if urn not in u:
+                raise ValueError(
+                    '%s not found in pool %s.' % (urn, self.getId()))
+
             self.removeUrn(urn)
             c[prod]['sn'].remove(sn)
+
             if len(c[prod]['sn']) == 0:
                 del c[prod]
             try:
@@ -263,8 +327,7 @@ When implementing a ProductPool, the following rules need to be applied:
             except Exception as e:
                 msg = 'product ' + urn + ' removal failed'
                 logger.debug(msg)
-                # undo changes
-                c, t, u = cs, ts, us
+                self._classes, self._tags, self._urns = self.readHK()
                 raise e
         return res
 
@@ -291,12 +354,12 @@ When implementing a ProductPool, the following rules need to be applied:
         Save/Update descriptors in pool.
         """
 
-    def schematicSave(self, resourcetype, index, data, tag=None):
+    def schematicSave(self, resourcetype, index, data, tag=None, **kwds):
         """ to be implemented by subclasses to do the scheme-specific saving
         """
         raise(NotImplementedError)
 
-    def saveProduct(self,  product, tag=None, geturnobjs=False, serialized=False):
+    def saveProduct(self,  product, tag=None, geturnobjs=False, serialized=False, **kwds):
         """
         Saves specified product and returns the designated ProductRefs or URNs.
         Saves a product or a list of products to the pool, possibly under the
@@ -307,9 +370,6 @@ When implementing a ProductPool, the following rules need to be applied:
 
         serialized: if True returns contents in serialized form.
         """
-        c, t, u = self._classes, self._tags, self._urns
-        # save a copy
-        cs, ts, us = deepcopy(c), deepcopy(t), deepcopy(u)
 
         if not issubclass(product.__class__, list):
             prds = [product]
@@ -320,6 +380,14 @@ When implementing a ProductPool, the following rules need to be applied:
             pn = fullname(prd)
             with filelock.FileLock(self.lockpath('w')),\
                     filelock.FileLock(self.lockpath('r')):
+
+                # get the latest HK
+                self._classes, self._tags, self._urns = self.readHK()
+                c, t, u = self._classes, self._tags, self._urns
+                if 0:  # prd.creator in ['Todds', 'Cassandra', 'Jane']:
+                    import pdb
+                    pdb.set_trace()
+
                 if pn in c:
                     sn = (c[pn]['currentSN'] + 1)
                 else:
@@ -338,17 +406,19 @@ When implementing a ProductPool, the following rules need to be applied:
 
                 if tag is not None:
                     self.setTag(tag, urn)
-
                 try:
+                    # save prod and HK
                     self.schematicSave(resourcetype=pn,
                                        index=sn,
-                                       data=prd,  tag=tag)
+                                       data=prd,
+                                       tag=tag,
+                                       **kwds)
                 except Exception as e:
-                    msg = 'product ' + urn + ' saving failed'
+                    msg = 'product ' + urn + ' saving failed.'
+                    self._classes, self._tags, self._urns = self.readHK()
                     logger.debug(msg)
-                    # undo changes
-                    c, t, u = cs, ts, us
                     raise e
+
             if geturnobjs:
                 if serialized:
                     res.append(urn)
@@ -540,4 +610,13 @@ When implementing a ProductPool, the following rules need to be applied:
         return ret
 
     def __repr__(self):
-        return self.__class__.__name__ + ' { pool= ' + str(self._poolname) + ' }'
+        return self.__class__.__name__ + ' < pool= ' + str(self._poolname) + ' >'
+
+    def __getstate__(self):
+        """ returns an odict that has all state info of this object.
+        Subclasses should override this function.
+        """
+        return ODict(
+            poolname=self._poolname,
+            poolurl=self._poolurl
+        )
